_Journal of Sport Rehabilitation,_ 2015, 24, 13-20
<http://dx.doi.org/10.1123/JSR.2013-0097>
© 2015 Human Kinetics, Inc.

**\<www.JSR-Journal.com>**

ORIGINAL RESEARCH REPORT

# **The Validity of the Nordic Hamstring Lower** **for a Field-Based Assessment of Eccentric** **Hamstring Strength**

**Emma Sconce, Paul Jones, Ellena Turner, Paul Comfort, and Philip Graham-Smith**

_**Context**_ _:_ Hamstring injury-risk assessment has primarily been investigated using isokinetic dynamometry.
However, practical issues such as cost and availability limit the widespread application of isokinetics for
injury-risk assessment; thus, field-based alternatives for assessing eccentric hamstring strength are needed.
_**Objective**_ _:_ The aim of this study was to investigate the validity of the angle achieved during Nordic hamstring
lowers (break-point angle) as a field-based test for eccentric hamstring strength. _**Design**_ _:_ Exploratory study.
_**Setting**_ _:_ Laboratory. _**Participants**_ _:_ Sixteen male (n = 7) and female (n = 9) soccer players (mean ± SD age 24
± 6 y, height 1.77 ± 0.12 m, and body mass 68.5 ± 16.5 kg) acted as subjects for the study. _**Main Outcome**_
_**Measures**_ _:_ The authors explored relationships between the Nordic break-point angle (the point at which the
subject can no longer resist the increasing gravitational moment during a Nordic hamstring lower) measured
from video and isokinetic peak torque and angle of peak torque of right- and left-knee flexors. _**Results**_ _:_ The
results revealed a meaningful relationship between eccentric knee-flexor peak torque (average of right and
left limbs) and the Nordic break-point angle ( _r_ = –.808, _r_ \[2\] = 65%, _P_ \< .00001). However, there was a weak
relationship observed ( _r_ = .480, _r_ \[2\] = 23%, _P_ = .06) between break-point angle and the angle of peak torque
(average of right and left limbs). _**Conclusions**_ _:_ The results suggest that the break-point angle achieved during
Nordic hamstring lowers could be used as a field-based assessment of eccentric hamstring strength.

_**Keywords:**_ break-point angle, peak torque, angle of peak torque, angle of crossover, hamstring injury risk

Hamstring injuries are common in a number of
sprint-related sports, accounting for 29% of injuries
among sprinters, \[1\] whereas 12% of all injuries reported
over 2 seasons in professional soccer players were hamstring strains. \[2\] In an analysis of English professional
rugby union match injuries over 2 seasons, \[3\] hamstring
injuries were the second-most-common injury, while in
training, \[4\] hamstring injuries were most frequent. Furthermore, players involved in more high-speed-running
actions (eg, backs) accumulated more hamstring strains. \[3,4\]
The literature suggests that there are 2 noncontact
mechanisms responsible for hamstring strain—one resulting from high-speed running, as in soccer \[5\] and track and
field events, \[6\] and the other during stretching movements
carried out to extreme range of motion, \[7\] both resulting in
high-velocity eccentric loading. \[8–10\] Strain injury usually
occurs late in the swing phase or early in the stance phase
of the gait cycle. \[11,12\] During late swing the hamstrings
work eccentrically to decelerate both the thigh and lower

The authors are with the Research Centre for Health, Sport
and Rehabilitation Sciences, University of Salford, Greater
Manchester, United Kingdom. Address author correspondence
to Paul Jones at <P.A.Jones@salford.ac.uk>

leg in preparation for ground contact. Eccentric hamstring weakness has been associated with a history of
hamstring strains, \[13,14\] and many studies have shown that
eccentric hamstring training can reduce the incidence of
hamstring strains. \[7,15–18\] Furthermore, the angle of peak
torque has been considered as a risk factor for hamstring
injuries, \[8,15,19,20\] with angle of peak torque achieved at
shorter muscle lengths associated with hamstring injury,
as the muscle is vulnerable for a longer period. \[15,19\]
Many intrinsic risk factors exist, such as poor lumbar
posture, \[21\] previous injury, \[5,22\] lack of flexibility, \[13\] and
insufficient hamstring strength in relation to the opposing quadriceps or contralateral hamstrings. \[23\] Previous
attempts at screening for potential hamstring injury have
centered on the use of isokinetics to examine the ratio
of flexor (hamstring) to extensor (quadriceps) muscle
strength, through either a traditional concentric-flexor/
concentric-extensor peak-torque ratio \[9,22,23\] or dynamic
control ratio (eccentric knee flexor/concentric knee
extensor). \[22,24\] One criticism of these ratios is that they
only take into account the peak-torque values, which can
occur at different angular positions in the overall range of
motion and are not joint-angle specific. Thus, an angle of
crossover has recently been recommended that considers
reciprocal knee-joint muscle balance throughout the full
range of motion. \[25\]

**13**

**14** Sconce et al

Although isokinetics have also been used to evaluate
hamstring injuries retrospectively by assessing eccentric
hamstring strength \[13\] and angle of peak torque, \[8\] a major
drawback of using isokinetics for assessing hamstring
strength and reciprocal knee-joint muscle balance for
injury screening is the accessibility of isokinetic equipment for practitioners. Furthermore, isokinetic testing
is expensive and time-consuming and may be regarded
as nonfunctional with regard to most sporting actions.
Moreover, often assessments are performed in a seated
position, \[8,9,13,14,22–24\] which may further limit the investigation of relationships to functional activities with the hip in
an extended position. Therefore, there is a need to develop
alternative tests of eccentric hamstring strength, particularly those that can be used in the field by practitioners.
The inclusion of hamstring exercises such as Nordic
curls (Nordic hamstring lowers) in a training program
has been shown to improve hamstring strength by 11%
and dynamic-control ratios in soccer players over 10
weeks, \[26\] reduce the angle of peak torque (closer to full
knee extension) for the hamstrings in athletic males, \[20\]
and reduce the incidence of hamstring injuries in various
team-sport athletes during the subsequent season. \[16–18\]
Theoretically, the greater range achieved by an individual
during a Nordic hamstring lower reflects the individual’s
eccentric hamstring strength, as the gravitational moment
progressively increases throughout the range of the
exercise (Figure 1). Therefore, the “break point” (the
angle at which the individual can no longer resist the
increasing gravitational moment and falls to the floor)
could be used as an assessment of eccentric hamstring
strength. One previous investigation reported that the
break-point angle was significantly correlated with peak
concentric hamstring torque at both 60°/s and 240°/s. \[27\]
The aim of this study was to assess the validity of the
Nordic hamstring-lower exercise to assess eccentric
hamstring strength. The relationship between the break
point achieved by individuals during Nordic hamstring
lowers (Figure 1) and peak eccentric knee-flexor torque as
measured during isokinetic dynamometry was explored.
We hypothesized that the break point would be related to
isokinetic peak eccentric knee-flexor torque. If such as
relationship does exist, it provides support for the use of
the Nordic break-point test as a field-based assessment
for eccentric hamstring strength and would overcome
many of the practical limitations of isokinetic testing.

## **Methods**

**Design**

To investigate the study hypothesis and validate the use of
the Nordic break-point angle as a field-based assessment
of eccentric hamstring strength, a cross-sectional design
was used to explore relationships between the Nordic
break-point angle (the point at which the subject can no
longer resist the increasing gravitational moment during
a Nordic hamstring lower \[Figure 1\]) measured from
video and traditional measures of eccentric hamstring

**Figure 1** — Nordic hamstring-lower exercise: (a) start, (b)
midpoint indicating the Nordic break-point angle, and (c) end.

strength such as isokinetic eccentric knee-flexor peak
torque (average of right and left limbs). Furthermore,
the relationship between Nordic break-point angle and
angle of peak torque (average of right and left limbs) and
a new method of reciprocal knee-joint muscle balance
(average of right and left) and the angle of crossover, \[25\]
was also explored.

**Participants**

Sixteen male (n = 7) and female (n = 9) soccer players of
various playing positions, experience, and ability acted
as subjects for the study (mean ± SD age 24 ± 6 y, height
1.77 ± 0.12 m, and body mass 68.5 ± 16.5 kg). The study
was approved by the university’s ethical committee, and
all subjects provided written informed consent to participate in the spirit of the Helsinki declaration.

Nordic Hamstring Lowers as a Measure of Eccentric Strength **15**

**Procedures**

After familiarization with the test procedures, each subject attended the laboratory for isokinetic assessment
and video recording of 3 Nordic hamstring lowers. Each
subject was asked to refrain from strenuous exercise or
training 48 hours before assessments and to avoid eating
2 hours before testing. All equipment used was calibrated
according to manufacturers’ standardized procedures.
Gravity-corrected isokinetic peak torque and angle of
peak torque of the knee flexors and extensors of the right
and left legs was assessed at 60°/s in both concentric and
eccentric modes using a Kin Com isokinetic dynamometer (Chattanooga Group, Tennessee). The subjects were
seated with the hip joint at 90° (supine position = 0°). The
seated position was chosen due to the consistent approach
used in several previous studies. \[7–9,13,14,22–24\] The axis of
rotation of the dynamometer shaft was aligned with the
best approximation of the knee axis of rotation, midway
between the lateral condyles of the femur and tibia. The
cuff of the dynamometer lever arm was attached to the
ankle 5 cm proximal to the malleoli, and the moment arm
recorded for gravity correction. Extraneous movement
was prevented by straps positioned at the hip, shoulders,
and tested thigh. Subjects were also instructed to hold
onto the handles located underneath the seat. A range
of motion was set as close to 90° as possible, zero being
full knee extension.
Eight submaximal concentric knee-extension and
-flexion movements were performed as part of a warm-up.
This followed 3 minutes of stationary cycling (60 rpm) on
a cycle ergometer (Wattbike Ltd, Nottingham, UK). The

“overlay” method was selected for data collection, as this
generates individual angle–torque graphs per repetition,
enabling the graph with the greatest torque to be saved
for subsequent analysis. Concentric and eccentric strength
of the extensors were measured before concentric and
eccentric strength of the knee flexors. Four maximaleffort movements were performed in each mode, with
10 seconds recovery between efforts. \[28\] The resistance
provided by the weight of the lower leg was recorded at
30° of flexion, to avoid excessive pull of the hamstrings
to allow for gravity correction. \[28\]
Data were exported in ASCII format into Microsoft
Excel, where a number of variables were calculated. The
ends of range of movement that had corresponding phases
of acceleration and deceleration were deleted from the
analysis. A tolerance of ±1°/s was permitted.
In addition, the dynamic-control profile \[25\] was determined (Figure 2), which involves representing the net
joint torque (eccentric flexor minus concentric extensor)
over the entire range of motion and identifies the range
of motion in which the quadriceps concentrically are
stronger than the hamstrings eccentrically and hence the
potential for injury risk. The point where the net joint
torque crosses zero is known as the angle of crossover.
The angle of crossover has been shown to be a reliable
technique to assess knee flexor–extensor muscle balance
and to discriminate retrospectively between hamstringinjured and -noninjured athletes. \[25\]
Each subject performed 3 trials of Nordic hamstring lowers (Figure 1). Each trial was recorded using
a Casio Exlim-F1 camera (60 Hz) placed in the sagittal
plane positioned 5 m away. Quintic Biomechanics v 17

**Figure 2** — The dynamic control profile represents the net joint torque (eccentric hamstring – concentric quadriceps) throughout
the full range of motion (0° \[full knee extension\] to 90° of flexion). The point at which the net joint torque crosses zero on the _x_ -axis
is the angle of crossover, whereby the torque generated by the quadriceps concentrically supersedes the hamstrings eccentrically.

**16** Sconce et al

(Coventry, UK) was subsequently used to determine the
angle from the greater trochanter (hip) to lateral epicondyle (knee) relative to the horizontal from the recorded
video. Each video image was calibrated using a filmed
1-m × 1-m calibration frame before analysis. The exercise protocol included every individual being informed
to remain with the hips fixed in line with the knee and
shoulder joints throughout the range of movement. \[26\]
The subject assumed a kneeling position with a partner
attempting to apply pressure onto the subject’s heels
(Figure 1). From this position, the subject performed a
forward-falling action. The subject’s head, trunk, and
thighs were lowered forward via knee extension until he
or she could no longer withstand the force of the “fall,”
with the hamstrings providing the main resistance against
gravity. \[29\] Arms and hands were used to buffer the fall,
letting the chest touch the surface. \[26\] Every subject had 3
submaximal warm-up repetitions to ensure that correct
technique was understood and followed. The best Nordic
break-point-angle result (lowest, closer to floor) for every
subject was determined and used in subsequent statistical
analysis. Pilot data collected on 11 female soccer players
revealed high relative (the degree to which individuals
maintain their position in a sample of repeated measures \[30\] ) (intraclass correlation coefficient \[ICC\] = .969,
95% confidence interval = .910–.992) and absolute (the
degree to which repeated measurements vary for individuals \[30\] ) within-session reliability (coefficient of variation

\[CV\] = 4.85%, standard error of measurement \[SEM\] =
1.47°) for the Nordic break-point angle.

**Statistical Analyses**

All data were analyzed using statistical-analysis software,
SPSS v 16.0 for Windows (Chicago, IL). Normality of
data was confirmed using a Shapiro Wilks test. Significance was set at _P_ \< .05. An independent-samples _T_ -test
was used to determine any significant differences between
genders (male vs female) for each variable.
Pearson product–moment correlation ( _r_ ) was used
to explore relationships between eccentric flexor peak
torque, angle of peak torque, angle of crossover (average
of right and left limbs), and break-point angle during the
Nordic hamstring lowers. Coefficients of determination
( _r_ \[2\] × 100) were used to interpret the meaningfulness of
the relationships. Using criteria from Thomas et al, \[31\]
when common variance (coefficient of determination)

between 2 variables falls below 50% (Pearson correlation
£ .71), it indicates that the variables are specific or somewhat independent in nature. \[31\] Post hoc observed power
calculations for correlation analysis were performed in
G\*Power v 3.1.5, Germany. \[32\]

## **Results**

Descriptive statistics for each variable are shown in Table

1. Women’s eccentric and concentric hamstring peak
   torques were significantly lower ( _P_ \< .001) than men’s
   (Table 1). Women’s Nordic break-point angles were significantly higher ( _P_ \< .05) than men’s (Table 1). Women’s
   angles of peak torque were significantly higher ( _P_ \< .05)
   than men’s (Table 1). Women’s angles of crossover were
   significantly lower ( _P_ \< .05) than men’s (Table 1).
   Pearson correlation and coefficient of determination revealed a meaningful relationship ( _r_ = –.808, _r_ \[2\] =
   65%, n = 16, _P_ \< .00001, power = 0.96) between Nordic
   break-point angle and eccentric knee-flexor peak torque
   (average peak torque for right and left limbs; Figure 3).
   However, a weak relationship ( _r_ = .480, _r_ \[2\] = 23%, n =
   16, _P_ = .06, power = 0.95) was found between Nordic
   break-point angle and angle of peak torque (average of
   right and left limbs; Figure 4).
   The data also revealed a meaningful relationship ( _r_ =
   –.717, _r_ \[2\] = 51%, n = 16, _P_ \< .002, power = .96) between
   Nordic break-point angle and the angle of crossover
   (average of left and right limbs; Figure 5).

## **Discussion**

The results of the study reveal that the Nordic break-point
angle is related to eccentric knee-flexor peak torque,
providing support for the use of this field-based test and
substantiating the study hypothesis. The Nordic breakpoint angle was also considered to be highly reliable, with
an ICC of .969, and possess low absolute error (CV =
4.85%, SEM = 1.47°), which is comparable to the findings
of Lee et al, \[27\] providing further support for its use in the
field. Given that eccentric weakness is associated with
hamstring injuries, \[13,14\] future studies need to evaluate
whether field-based tests such as the Nordic break-pointangle test can prospectively predict hamstring-injury
occurrence and, possibly more important, determine
whether, if this angle is decreased (ie, a lower angle

**Table 1 Mean ± SD for Each Variable Considered in the Study**

**Variable** **Whole group (N = 16)** **Men (n = 7)** **Women (n = 9)**

Eccentric knee-flexor peak torque (Nm) 131.9 ± 50.7 177.3 ± 38.2\* 96.7 ± 23.0

Concentric knee-flexor peak torque (Nm) 107.0 ± 38.7 143.4 ± 27.7\* 78.7 ± 13.3

Nordic break-point angle (°) 41 ± 8.1 36 ± 5.9† 46 ± 7.0

Angle of peak torque (°) 27.2 ± 8.1 22.9 ± 5.4† 30.6 ± 8.5

Angle of crossover (°) 37.1 ± 11.9 43.6 ± 10.5‡ 32 ± 10.9

\*Men significantly greater than women ( _P_ \< .001). †Men significantly lower than women ( _P_ \< .05). ‡Men significantly higher than women ( _P_ \< .05).

Nordic Hamstring Lowers as a Measure of Eccentric Strength **17**

**Figure 3** — Scatter graph illustrating the relationship between Nordic break-point angle and eccentric knee-flexor peak torque
(average of right and left limbs).

**Figure 4** — Scatter graph illustrating a potential relationship between Nordic break-point angle and eccentric knee-flexor angle of
peak torque (average of right and left limbs).

would indicate closer to floor, greater eccentric strength),
it further decreases the risk of hamstring injury.
The results revealed a greater than 50% shared
common variance ( _r_ = –.808, _r_ \[2\] = 65%) between Nordic
break-point angle and eccentric knee-flexor peak torque,
suggesting that both measures are not independent and
are related. \[31\] This is in contrast to the findings of Lee et
al, \[27\] who found no relationship between break-point angle
and eccentric peak torque. Lee et al, \[27\] however, did find

a significant correlation with peak concentric hamstring
torque at both 60°/s and 240°/s and break-point angle.
Eccentric hamstring weakness has been associated
with a history of hamstring strains, \[13,14\] and many studies have shown that eccentric hamstring training can
reduce the incidence of hamstring strains. \[7,16–18\] Isokinetic
assessment has been widely used in hamstring injury-risk
assessment \[9,23\] and is perhaps the only reliable way to
measure eccentric hamstring strength. However, due to a

**18** Sconce et al

**Figure 5** — Scatter graph illustrating the relationship between Nordic break-point angle and angle of crossover (average of right
and left limbs).

range of practical difficulties, the widespread application
of isokinetics for injury risk assessment is limited. Thus,
the need to develop field-based assessments of eccentric
hamstring strength is of prime importance to aid in injury
screening of athletes.
A weak relationship was observed between Nordic
break-point angle and knee-flexor angle of peak torque
( _r_ = .480, n = 16, _r_ \[2\] = 23%). With regard to hamstringinjury risk assessment, such a relationship is important,
as Brockett et al, \[8\] found that previously injured muscles
reach peak torque at significantly shorter lengths (40.9°
± 2.7°) than the uninjured muscles of the opposite leg
(29.8° ± 1.5°) and muscles of both legs in an uninjured
group (right = 30.1° ± 1.5°, left = 17.3° ± 1.2°), the
hypothesis being that the microscopic damage from
eccentric exercise depends on the muscle’s optimum
length for active tension, proposing that optimal length
is a measure of susceptibility for muscle strains. \[8\] It is
reported that the greater the knee-extension angle (lower
angle of flexion) at which peak torque is produced, the
lower the risk of hamstring injury. \[8\] Even though muscle
balance may be satisfactory after rehabilitation, a major
difference between the injured limb and the noninjured
limb is the position of peak torque. \[8\] Previous studies have
also shown that acute \[19\] and chronic (4 wk) \[20\] adaptations
to Nordic hamstring lowers involve alteration in the
length–tension relationship of hamstrings, with a shift in
the angle of peak torque to longer lengths (closer to full
knee extension). The lack of a strong relationship between
Nordic break-point angle and knee-flexor angle of peak
torque is perhaps due to the different hip positions used
in the 2 tests (flexed during isokinetics and straight during
Nordic hamstring lowers). This is perhaps a limitation
of the current study in that isokinetic assessments were

not made with the subjects in a supine rather than seated
position and thus allow for length–tension status of the
hamstrings similar to that in the Nordic hamstring lower.
Given that both measures were significantly ( _P_ \< .05)
different between men and women in this study and that
Figure 4 reveals a potential linear relationship, greater
similarity between hip positions in both assessments
may lead to a stronger relationship and provide further
support for the use of the Nordic break-point angle for
hamstring-injury risk assessment. Future studies should
explore relationships between Nordic break-point angle
and isokinetic knee-flexor peak torque and angle of peak
torque in a supine position.
A limitation of the Nordic break-point-angle assessment is that in regard to hamstring-injury risk screening it does not consider the role of the quadriceps and
cocontraction synergy between the 2 muscle groups.
In activities such as high-speed running or stretching
movements carried out to the extreme range of motion,
hamstring strain may result from an eccentric hamstrings
muscle action failing to counteract excessive torque generated by the quadriceps due to deficits in intermuscular
coordination between the 2 muscle groups. Assessments
such as the Nordic break-point angle do not evaluate
this potential cause of hamstring strain. The results of
the current study revealed a greater than 50% shared
common variance ( _r_ = –.717, _r_ \[2\] = 51%) between angle
of crossover and Nordic break-point angle. This suggests that the variables are not independent and can be
considered related measures. \[31\] The angle of crossover is
a new method of assessing reciprocal knee-joint muscle
balance \[25\] that identifies the range of motion in which the
knee extensors are stronger than the knee flexors, with
a greater angle desirable for reduced risk of hamstring

Nordic Hamstring Lowers as a Measure of Eccentric Strength **19**

injury. \[25\] Thus, the results of the current study illustrate
that achieving a greater break-point angle is associated
with a greater angle of crossover and, thus, an improved
range in which the eccentric flexors are stronger than
the concentric extensors and potentially reduced risk of
hamstring injury. However, it should be cautioned that
limited research has fully evaluated the angle of crossover
with regard to hamstring-injury risk assessment.
Potential limitations of using the Nordic breakpoint-angle test for field-based assessment of eccentric
hamstring strength are that the Nordic hamstring lower
is a bilateral leg-strength exercise and thus does not isolate bilateral differences in eccentric hamstring strength,
unlike the use of an isokinetic dynamometer. Therefore,
future studies need to evaluate whether such assessments
can be performed unilaterally. Furthermore, no athletes
in the current study could complete the Nordic hamstring
lower throughout the whole range of motion. Typically,
when athletes can achieve this, weight is added to the
trunk through holding weight disks or wearing a weighted
vest. Thus, further research needs to consider how adding
weight can be integrated into the assessment for athletes
who complete a Nordic hamstring lower throughout the
full range of motion.
A further limitation is whether the Nordic test can be
applied across different sports; for example, rugby players, who have a greater upper-body mass, may achieve
a larger (ie, farther from the floor) Nordic break-point
angle. Furthermore, the gender differences observed in
the current study may be partially explained by differences in upper-body mass between men and women.
Therefore, future research needs to consider some form
of correction factor based on trunk and upper-limb mass
to allow comparisons between sports and gender.
In conclusion, the results of the current study suggest that the Nordic break-point angle test is a reliable
and valid field-based assessment of eccentric hamstring
strength. Future research needs to evaluate whether such
an assessment can prospectively identify athletes at risk
for hamstring injury.

## **References**

1. Lysholm J, Wiklander J. Injuries in runners. _Am J_
   _Sports Med_ . 1987;15:168–171. PubMed doi:10.1177/
   036354658701500213

1. Hawkins RD, Hulse MA, Wilkinson C, Hodson A,

Gibson M. The Association Football Medical Research

Programme: an audit of injuries in professional football.
_Br J Sports Med_ . 2001;35:43–47. PubMed doi:10.1136/
bjsm.35.1.43
3\. Brooks JHM, Fuller CW, Kemp SPT, Reddin DB. Epidemiology of injuries in English professional rugby union: part
1 match injuries. _Br J Sports Med_ . 2005;39(10):757–766.
PubMed doi:10.1136/bjsm.2005.018135
4\. Brooks JHM, Fuller CW, Kemp SPT, Reddin DB. Epidemiology of injuries in English professional rugby union: part
2 training injuries. _Br J Sports Med_ . 2005;39(10):767–775.
PubMed

5. Woods C, Hawkins RD, Maltby S, Hulse M, Thomas A,
   Hodson A. The Football Association Medical Research

Programme: an audit of injuries in professional football—analysis of hamstring injuries. _Br J Sports Med_ .
2004;38:36–41. PubMed doi:10.1136/bjsm.2002.002352
6\. Yamamoto T. Relationship between hamstring strains
and leg muscle strength. _J Sports Med Phys Fitness_ .
1993;33:194–199. PubMed
7\. Askling C, Karlsson J, Thorstensson A. Hamstring
injury occurrence in elite soccer players after preseason
strength training with eccentric overload. _Scand J Med Sci_
_Sports_ . 2003;13:244–250. PubMed doi:10.1034/j.16000838.2003.00312.x

8. Brockett CL, Morgan DL, Proske U. Predicting hamstring strain injury in elite athletes. _Med Sci Sports_
   _Exerc_ . 2004;36:379–387. PubMed doi:10.1249/01.

MSS.0000117165.75832.05

9. Cameron M, Adams R, Maher C. Motor control and
   strength as predictors of hamstring injury in elite players
   of Australian football. _Phys Ther Sport_ . 2003;4:159–166.
   doi:10.1016/S1466-853X(03)00053-1

1. Kujala UM, Orava S, Jarvinen M. Hamstring injuries:
   current trends in treatment and prevention. _Sports Med_ .
   1997;23:397–404. PubMed doi:10.2165/00007256
   199723060-00005

1. Heiderscheit BC, Hoerth DM, Swanson SC, Thelen
   BJ, Thelen DG. Identifying the time of occurrence of a
   hamstring strain injury during treadmill running: a case
   study. _Clin Biomech (Bristol, Avon)_ . 2005;20:1072–1078.
   PubMed doi:10.1016/j.clinbiomech.2005.07.005

1. Thelen DG, Chumanov ES, Best TM, Swanson SC,
   Heiderscheit BC. Simulation of biceps femoris musculotendon mechanics during the swing phase of sprinting.
   _Med Sci Sports Exerc_ . 2005;37:1931–1938. PubMed
   doi:10.1249/01.mss.0000176674.42929.de

1. Jönhagen S, Nemeth G, Eriksson E. Hamstring injuries in sprinters: the role of concentric
   and eccentric hamstring muscle strength and flexibility. _Am J Sports Med_ . 1994;22:262–266. PubMed
   doi:10.1177/036354659402200218

1. Croisier JL, Forthomme B, Namurois MH, Vanderthommen M, Crielaard JM. Hamstring muscle strain recurrence
   and strength performance disorders. _Am J Sports Med_ .
   2002;30:199–203. PubMed

1. Proske U, Morgan D, Brockett C, Percival P. Identifying
   athletes at risk of hamstring strains and how to protect
   them. _Clin Exp Pharmacol Physiol_ . 2004;31:546–550.
   PubMed doi:10.1111/j.1440-1681.2004.04028.x

1. Gabbe BJ, Branson R, Bennell KL. A pilot randomised
   controlled trial of eccentric exercise to prevent hamstring
   injuries in community-level Australian football. _J Sci_
   _Med Sport_ . 2006;9:103–109. PubMed doi:10.1016/j.
   jsams.2006.02.001

1. Brooks JHM, Fuller CW, Kemp SPT, Reddin DB. Incidence, risk and prevention of hamstring muscle injuries in
   professional rugby union. _Am J Sports Med_ . 2006;34:1297–

1. PubMed doi:10.1177/0363546505286022

1. Arnason A, Anderson TE, Holme I, Engebretsen L, Bahr
   R. Prevention of hamstring strains in elite soccer: an inter

**20** Sconce et al

vention study. _Scand J Med Sci Sports_ . 2008;18:40–48.
PubMed doi:10.1111/j.1600-0838.2006.00634.x
19\. Brockett CL, Morgan DL, Proske U. Human hamstring
muscles adapt to eccentric exercise by changing optimal
length. _Med Sci Sports Exerc_ . 2001;33:783–790. PubMed
doi:10.1097/00005768-200105000-00017

20. Clark R, Bryant A, Culgan JP, Hartley B. The effects of
    eccentric hamstring strength training on dynamic jumping
    performance and isokinetic strength parameters: a pilot
    study on the implications for the prevention of hamstring
    injuries. _Phys Ther Sport_ . 2005;6:67–73. doi:10.1016/j.
    ptsp.2005.02.003

01. Hennessey L, Watson AWS. Flexibility and posture assessment in relation to hamstring injury. _Br J Sports Med_ .
    1993;27:243–246. PubMed doi:10.1136/bjsm.27.4.243

01. Bennell K, Wajswelner H, Lew P, Schall-Riacour A,
    Leslie S, Plant D. Isokinetic strength testing does not
    predict hamstring injury in Australian Rules footballers.
    _Br J Sports Med_ . 1998;32:309–314. PubMed doi:10.1136/
    bjsm.32.4.309

01. Orchard J, Marsden J, Lord S, Garlick D. Preseason hamstring muscle weakness associated with hamstring injury in
    Australian footballers. _Am J Sports Med_ . 1997;25:81–85.
    PubMed doi:10.1177/036354659702500116

01. Aagaard P, Simonsen EB, Magnusson SP, Larsson B,
    Dyhre-Poulsen P. A new concept for isokinetic hamstring:
    quadriceps muscle strength ratio. _Am J Sports Med_ .
    1998;26:231–237. PubMed

01. Graham-Smith P, Jones PA, Comfort P, Munro AG. Assessment of knee flexor and extensor muscle balance. _Int J Athl_
    _Ther Train_ . 2013;18(5):1–5.

01. Mjølsnes R, Arnason A, Osthagen T, Raastad T, Bahr
    R. A 10-week randomised trial comparing eccentric vs
    concentric hamstring strength training in well-trained
    soccer players. _Scand J Med Sci Sports_ . 2004;14:311–317.
    PubMed doi:10.1046/j.1600-0838.2003.367.x

01. Lee JW, Yung PS, Chan HC, Chan K. Reliability and validity of a novel field-based hamstring strength test for soccer
    players: implications for preventing hamstring injuries.
    Paper presented at: NSCA Conference; July 2013; Las
    Vegas, NV.

01. Baltzopoulos V. Isokinetic dynamometry. In: Payton C,
    Bartlett R, eds. _Biomechanical Evaluation of Movement_
    _in Sport and Exercise. The British Association of Sport_
    _and Exercise Sciences Guidelines_ . London: Routledge;
    2008:103–128.

01. Tansel RB, Slci Y, Yildirim A, Kocak S, Korkusuz F. Effects
    of eccentric hamstring strength training on lower extremity
    strength of 10–12 year old male basketball players. _Isokinet_
    _Exerc Sci_ . 2008;16:81–85.

01. Atkinson G, Nevill AM. Statistical methods for assessing
    measurement error (reliability) in variables relevant to
    sports medicine. _Sports Med_ . 1998;26:217–238. PubMed
    doi:10.2165/00007256-199826040-00002

01. Thomas JR, Nelson JK, Silverman SJ. _Research Methods_
    _in Physical Activity_ . Champaign, IL: Human Kinetics;

01.

01. Faul F, Erdfelder E, Buchner A, Lang AG. Statistical power
    analyses using G\*Power 3.1: tests for correlation and
    regression analyses. _Behav Res Methods_ . 2009;41:1149–

01. PubMed doi:10.3758/BRM.41.4.1149

Copyright of Journal of Sport Rehabilitation is the property of Human Kinetics Publishers,
Inc. and its content may not be copied or emailed to multiple sites or posted to a listserv
without the copyright holder's express written permission. However, users may print,
download, or email articles for individual use.
